from tier import Tier


class OozieSlave(Tier):
    tier = "oozie-slave"
    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "pig", "tapp2", "cloudman"]
    def __init__(self, subparser):
        super(OozieSlave, self).__init__(subparser)
